/*
 * time_util.c
 *
 * Copyright (c) 2003 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is licensed under the terms of the GNU Public License.  
 * See the file "license.terms" for restrictions on redistribution 
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */

/**
 * @file time_util.c
 *
 * Implementations of the functions in time_util.c.
 */

#include "config.h"

#include <stdio.h>
#include <string.h>

#include <sys/types.h>
#include <sys/time.h>

#include "assert_pp.h"
#include "time_util.h"

int string_to_microsec(unsigned long long *us_out, const char *str)
{
    char dead, units[3] = { 'u', 's', '\0' };
    int retval = 0;

    require(us_out != NULL);
    require(str != NULL);

    /* Clear the output value */
    *us_out = 0;

    /*
     * Scan the string for the number and an optional unit string.  We also
     * check for any extra characters that should not be in the input.  In
     * other words, if sscanf matches the extra character, we know there is
     * garbage at the end of the input.
     */
    switch( sscanf(str, "%qu%c%c%c", us_out, &units[0], &units[1], &dead) )
    {
    case 1: /* Only the number matched, use the default units. */
    case 3:
	if( strcmp(units, "us") == 0 )
	{
	    retval = 1;
	}
	else if( strcmp(units, "ms") == 0 )
	{
	    *us_out *= 1000;
	    retval = 1;
	}
	break;
    case 2:
	units[1] = '\0';
	if( strcmp(units, "s") == 0 )
	{
	    *us_out *= 1000000;
	    retval = 1;
	}
	else if( strcmp(units, "m") == 0 )
	{
	    *us_out *= 1000000 * 60;
	    retval = 1;
	}
	break;
    case 0:
	/* Nothing matched, bail out. */
	break;
    case 4:
	/* There is garbage at the end of the input. */
	break;
    case EOF:
	/* The string is empty. */
	break;
    default:
	ensure(0);
	break;
    }
    return( retval );
}
