/*
 * RTServerImpl.hh
 *
 * Copyright (c) 2003 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is licensed under the terms of the GNU Public License.  
 * See the file "license.terms" for restrictions on redistribution 
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */

/**
 * @file RTServerImpl.hh
 *
 * Header file for the RTServerImpl class.
 */

#ifndef _rt_server_hh
#define _rt_server_hh

#include "RTServerS.h"

/**
 * Basic implementation of the RTServer interface.
 */
class RTServerImpl : public virtual POA_RTServer
{

public:

    /**
     * Construct an RTServerImpl with the given values.
     *
     * @param deadline_us The server's deadline, in microseconds.
     * @param compute_us An array that describes the number of microseconds of
     * CPU to consume for each period.  When the end of the array is reached,
     * the server will cycle back to the beginning of the array.  The array is
     * kept by reference and not copied.
     * @param compute_us_length The number of elements in the 'compute_us'
     * array.
     */
    RTServerImpl(CORBA::ULong deadline_us,
		 const CORBA::ULong *compute_us,
		 unsigned int compute_us_length);

    /**
     * Consume the number of microseconds specified by
     * rts_Compute.data[rts_Compute.index].
     *
     * @sideeffect rts_Compute.index is incremented.
     *
     * @copydoc RTServer::Periodic
     */
    virtual void Periodic(void)
      throw (CORBA::SystemException);

protected:

    /**
     * The server's deadline, in microseconds.
     */
    CORBA::ULong rts_Deadline;

    /**
     * The description of the computation to be done.
     */
    struct {
	const CORBA::ULong *data;	/**< The array passed into the
					   constructor. */
	unsigned int length;	/**< The number of elements in the array. */
	unsigned int index;	/**< The next index in the array to use. */
    } rts_Compute;
    
};

#endif
